[Avn, Bvn, Cvn, Dvn] = vehicle_nom;
%  Inputs  =  10
%    1    Throttle Input dTh/Th for Engine No  1 (-)             
%    2    Throttle Input dTh/Th for Engine No  2 (-)             
%    3    Throttle Input dTh/Th for Engine No  3 (-)             
%    4    Aero Surface No  1 Elevon Deflect (radians)             
%    5    Aero Surface No  2 Aileron Deflect (radians)             
%    6    Aero Surface No  3 Rudder-1 Deflect (radians)             
%    7    Aero Surface No  4 Rudder-2 Deflect (radians)             
%    8    Aero Surface No  5 Speed-Brk Deflect (radians)             
%    9    Aero Surface No  6 Body-Flap Deflect (radians)             
%   10    Wind Gust Azim, Elev Angles=(-135.0  90.0) (deg)       
 
%  States  =  10
%    1    Roll Attitude     (phi-rigid)    (radians)             
%    2    Roll Rate         ( p -rigid)    (rad/sec)             
%    3    Pitch Attitude    (theta-rigid)  (radians)             
%    4    Pitch Rate        ( q -rigid)    (rad/sec)             
%    5    Yaw  Attitude     (psi-rigid)    (radians)             
%    6    Yaw  Rate         ( r -rigid)    (rad/sec)             
%    7    Angle of attack   (alfa-rigid)   (radians)             
%    8    Angle of sideslip (beta-rigid)   (radians)             
%    9    Change in Altitude (delta-h)      (feet)               
%   10    Change in Velocity (delta-V)      (ft/sec)             
 
%  Outputs =  14
%    1    Roll Attitude  (phi-body) (radians)                    
%    2    Roll Rate      (p-body)   (rad/sec)                    
%    3    Pitch Attitude (thet-bdy) (radians)                    
%    4    Pitch Rate     (q-body)   (rad/sec)                    
%    5    Yaw  Attitude  (psi-body) (radians)                    
%    6    Yaw  Rate      (r-body)   (rad/sec)                    
%    7    Angle of attack, alfa, (radians)                       
%    8    Angle of sideslip, beta, (radian)                      
%    9    Change in Altitude, delta-h, (feet)                    
%   10    Forward Acceleration  (V-dot)  (ft/sec)                
%   11    Cross Range Velocity (Vcr) (ft/sec)                    
%   12    CG Acceleration along X axis, (ft/sec^2)               
%   13    CG Acceleration along Y axis, (ft/sec^2)               
%   14    CG Acceleration along Z axis, (ft/sec^2)               

% Pitch Design System (includes phugoid states)
Ad= Avn([3,4,7,9,10],[3,4,7,9,10]);
Bd= Bvn([3,4,7,9,10],[4]);
Cd= Cvn([3,4,7,9,10],[3,4,7,9,10]);
Dd= Dvn([3,4,7,9,10],[4]);

%Q= [theta, q,   alfa, dh]
Q = [0.01, 0.2, 1,  0.000005, 0.4]*0.1; Q=diag(Q);    % Weight Matrices Q,
R= 2.5;                                       % R= Elevon
[Kp, s, e] = LQR(Ad,Bd,Q,R);                 % Pitch State-Feedback Matrix

% Lateral Design System
Ald= Avn([1,2,5,6,8],[1,2,5,6,8]);
Bld= Bvn([1,2,5,6,8],[5,6,7]);
Cld= Cvn([1,2,5,6,8],[1,2,5,6,8]);
Dld= Dvn([1,2,5,6,8],[5,6,7]);

%Q= [phi,  p,   psi,r,  beta]
Q = [0.005,0.2, 0.005,0.2, 1]*0.1; Q=diag(Q);   % Weight Matrices Q,
R=[5,5,5]*0.5; R=diag(R);                           % R= 3 control surf
[Kl, s, e] = LQR(Ald,Bld,Q,R);              % Later State-Feedback Matrix

