% Computes the Open-Loop Frequency Response for Flight Control Analysis
% Loop is opened at the Flight Control System Output
d2r=pi/180; r2d=180/pi; 
Npv=45;                                               % Number of Param Variations
% Load the sontrol loop subsystems
[Av, Bv, Cv, Dv]= vehicle;                            % Vehicle Nominal Model
[Au, Bu, Cu, Du]= vehicle_unc;                        % Vehicle Model with Uncertainties
[At, Bt, Ct, Dt]= actor_tvc;                          % Actuator + TVC Model
[As, Bs, Cs, Ds]= sensors;                            % Sensors Model
[Ac, Bc, Cc, Dc]= controller;                         % Controller
[Ap, Bp, Cp, Dp]= plant;                              % Combined Plant Model

label='Stage-2 Yaw Axis Stability, (Pitch & Roll Closed)';
[Ao,Bo,Co,Do]= linmod('Open_Loop');                   % Frequ Response Model (z-domain)
sys=ss(Ao,Bo,Co,Do);                                  % Perform Linearization
w=logspace(-2,2,12000);                               % and Frequ domain analysis
figure(1); Nichols(sys,w); title(label)
figure(2); Bode(sys,w); title(label)

w=logspace(-2,2,500);                              
[Acp,Bcp,Ccp,Dcp]=linmod('Closed_Loop_Unc'); 
sys=ss(Acp,Bcp,Ccp,Dcp);
sysf= FRD(sys,w);
blk=[-ones(Npv,1), zeros(Npv,1)];
[bnd,muinfo]= mussv(sysf,blk);

ff= get(muinfo.bnds, 'frequency');
muu=get(muinfo.bnds, 'responsedata');
muu=squeeze(muu);
muu=muu(1,:);
loglog(ff,muu)
xlabel('Frequency (rad/sec)')
ylabel('ssv')

% mu=ssv(Acp,Bcp,Ccp,Dcp,w);
% figure(3); loglog(w,mu);
%legend('Pitch','Lateral');
% title('Mu for 18 Variations')
